###############
Welcome to Moe!
###############
Moe is our resident Music-Organizer-Extraordinaire who's sole purpose is to give you full control over your music library. In other words, it's a commandline-interface for managing your music.

*******************
Development Warning
*******************
Moe is currently in early development, and is still training for his goal to become your all-powerful music library assistant. I do not recommend using Moe for anything except experimentation or testing until v1.0 is released.

So what can Moe do right now?
=============================
* Add music to your library, fixing tags with metadata from Musicbrainz.
* Organize, remove, list, and edit your music in the library.
* Supports including extra files with an album e.g. log or playlist files.
* Supports tags with multiple values.

If you want to learn more, check out the `Getting Started <https://mrmoe.readthedocs.io/en/latest/getting_started.html>`_ docs.
